==> yanmah2-1.5-noarch.zip: yanmah2-1.5-noarch/keywords_processor.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2009 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php defined("HELLO") or exit(); ?>
<?php
/*function getCache($path, $limit){
  $now = time();
  if (!file_exists($path)){
	return FALSE;
  } else {
	$old = filectime($path);
	$gap = $now - $old;
  }
  if ($gap > $limit){
	return FALSE;
  } else {
	return file_get_contents($path);
  }
}
function putCache($path, $data){
  return file_put_contents($path, $data, LOCK_EX);
}
function delCache($dir, $life){
	$now = time();
	$files = scandir($dir);
	$files = array_slice($files, 2);
	foreach($files as $val){
		$atime = fileatime($dir . '/' . $val);
		$gap = $now - $atime;
		if ($gap > $life) unlink($dir . '/' . $val);
	}
}

if ($use_cache === TRUE){
// 	var_dump($use_cache);
	if ($use_cache === TRUE){
		$cache = "{$kw_cache_dir}/".urlencode($request_url);
		$raw_contents = getCache($cache, $kw_cache_time);
	} else {
		$cache = "{$kw_cache_dir}/".urlencode($request_url);
		$raw_contents = FALSE;
	}
	if ($raw_contents != FALSE){
		$contents = json_decode($raw_contents, TRUE);
	} else {
// 		var_dump($cache);
	  $json = getJson($request_url, FALSE);
	  if ($json['stat'] !== TRUE){
		echo "<li>はてなハイク API から一覧を取得できませんでした。";
		echo "<blockquote>{$json['stat']}</blockquote></li>";
		return;
	  } else {
		$put = putCache($cache, $json['body']);
		$contents = json_decode($json['body'], TRUE);
	  }
	}
	$lot = rand(1,10);
	if ($lot == 1) delCache($kw_cache_dir, $kw_cache_time);*/
// } else {
	  $json = getJson($request_url, FALSE);
	  if ($json['stat'] !== TRUE){
		echo "<li>はてなハイク API から一覧を取得できませんでした。";
		echo "<blockquote>{$json['stat']}</blockquote></li>";
		return;
	  } else {
// 		$contents = json_decode($json['body'], TRUE);
		$contents = simplexml_load_string($json['body']);
	  }
// }
if (libxml_get_last_error() !== FALSE){
	$json = strip_tags($json['body']);
	echo "<li>はてなハイク API から一覧を取得できませんでした。";
	echo "<blockquote><pre>{$json}</pre></blockquote></li>";
} elseif (isset($contents['error'])){
	echo "<li>はてなハイク API から一覧を取得できませんでした。";
	echo "<blockquote><pre>{$contents['error']}</pre></blockquote></li>";
} else {
//	echo "<pre>"; var_dump($contents); echo "</pre>";
  if ($list_mode == 'related'){
	foreach ($contents->related_keywords as $val){
	  echo "<li><a href=\"./entries.php?keyword=";
	  echo rawurlencode($val);
	  if ($_GET['image'] == 'on') echo '&amp;image=on';
	  echo "\" class=\"keyword\">";
	  echo htmlspecialchars($val, ENT_QUOTES);
	  echo "</a></li>";
	}
  } else {
	foreach ($contents as $val){
	  echo "<li><a href=\"./entries.php?keyword=";
	  echo rawurlencode($val->word);
	  if ($_GET['image'] == 'on') echo '&amp;image=on';
	  echo "\" class=\"keyword\">";
	  echo htmlspecialchars($val->title, ENT_QUOTES);
	  echo "</a>(".$val->entry_count.")</li>";
	}
  }
}
?>

==> yanmah2-1.6-noarch.zip: yanmah2-1.6-noarch/keywords_processor.php <==
<?php
//YANMAH2 - Yet ANother Mobile Accelerated HatenaHaiku
//(c) 2009 YANMAH2 project
//This program is freesoftware. you can redistribute it and/ormodify it under the terms of the [GNU Affero GPL v3](http://www.gnu.org/licenses/agpl.html).
?>
<?php defined("HELLO") or exit(); ?>
<?php
/*function getCache($path, $limit){
  $now = time();
  if (!file_exists($path)){
	return FALSE;
  } else {
	$old = filectime($path);
	$gap = $now - $old;
  }
  if ($gap > $limit){
	return FALSE;
  } else {
	return file_get_contents($path);
  }
}
function putCache($path, $data){
  return file_put_contents($path, $data, LOCK_EX);
}
function delCache($dir, $life){
	$now = time();
	$files = scandir($dir);
	$files = array_slice($files, 2);
	foreach($files as $val){
		$atime = fileatime($dir . '/' . $val);
		$gap = $now - $atime;
		if ($gap > $life) unlink($dir . '/' . $val);
	}
}

if ($use_cache === TRUE){
// 	var_dump($use_cache);
	if ($use_cache === TRUE){
		$cache = "{$kw_cache_dir}/".urlencode($request_url);
		$raw_contents = getCache($cache, $kw_cache_time);
	} else {
		$cache = "{$kw_cache_dir}/".urlencode($request_url);
		$raw_contents = FALSE;
	}
	if ($raw_contents != FALSE){
		$contents = json_decode($raw_contents, TRUE);
	} else {
// 		var_dump($cache);
	  $json = getJson($request_url, FALSE);
	  if ($json['stat'] !== TRUE){
		echo "<li>はてなハイク API から一覧を取得できませんでした。";
		echo "<blockquote>{$json['stat']}</blockquote></li>";
		return;
	  } else {
		$put = putCache($cache, $json['body']);
		$contents = json_decode($json['body'], TRUE);
	  }
	}
	$lot = rand(1,10);
	if ($lot == 1) delCache($kw_cache_dir, $kw_cache_time);*/
// } else {
	  $json = getJson($request_url, FALSE);
	  if ($json['stat'] !== TRUE){
		echo "<li>はてなハイク API から一覧を取得できませんでした。";
		echo "<blockquote>{$json['stat']}</blockquote></li>";
		return;
	  } else {
// 		$contents = json_decode($json['body'], TRUE);
		$contents = simplexml_load_string($json['body']);
	  }
// }
if (libxml_get_last_error() !== FALSE){
	$json = strip_tags($json['body']);
	echo "<li>はてなハイク API から一覧を取得できませんでした。";
	echo "<blockquote><pre>{$json}</pre></blockquote></li>";
} elseif (isset($contents['error'])){
	echo "<li>はてなハイク API から一覧を取得できませんでした。";
	echo "<blockquote><pre>{$contents['error']}</pre></blockquote></li>";
} else {
//	echo "<pre>"; var_dump($contents); echo "</pre>";
  if (isset($list_mode) && $list_mode == 'related'){
	foreach ($contents->related_keywords as $val){
	  echo "<li><a href=\"./entries.php?keyword=";
	  echo rawurlencode($val);
	  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
	  echo "\" class=\"keyword\">";
	  echo htmlspecialchars($val, ENT_QUOTES);
	  echo "</a></li>";
	}
  } else {
	foreach ($contents as $val){
	  echo "<li><a href=\"./entries.php?keyword=";
	  echo rawurlencode($val->word);
	  if (isset($_GET['image']) && $_GET['image'] == 'on') echo '&amp;image=on';
	  echo "\" class=\"keyword\">";
	  echo htmlspecialchars($val->title, ENT_QUOTES);
	  echo "</a>(".$val->entry_count.")</li>";
	}
  }
}
?>
